/*
 * Copyright 2012-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.boot.actuate.endpoint;

import java.util.List;
import java.util.Map;

import org.junit.Test;

import org.springframework.boot.actuate.info.InfoContributor;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import static org.assertj.core.api.Assertions.assertThat;

/**
 * Tests for {@link InfoEndpoint}.
 *
 * @author Phillip Webb
 * @author Dave Syer
 * @author Meang Akira Tanaka
 */
public class InfoEndpointTests extends AbstractEndpointTests<InfoEndpoint> {

	public InfoEndpointTests() {
		super(Config.class, InfoEndpoint.class, "info", "endpoints.info");
	}

	@Test
	public void invoke() throws Exception {
		Map<String, Object> actual = getEndpointBean().invoke();
		assertThat(actual.get("key1")).isEqualTo("value1");
	}

	@Configuration
	@EnableConfigurationProperties
	public static class Config {

		@Bean
		public InfoContributor infoContributor() {
			return (builder) -> builder.withDetail("key1", "value1");
		}

		@Bean
		public InfoEndpoint endpoint(List<InfoContributor> infoContributors) {
			return new InfoEndpoint(infoContributors);
		}

	}

}
